@@ -148,7 +148,8 @@ sub new {
         $obj->status($acc);
 
         ### add minimum supported accessors
-        $acc->mk_accessors( qw[created installed uninstalled dist] );
+        $acc->mk_accessors( qw[prepared created installed uninstalled 
+                               distdir dist] );
     }
 
     ### now initialize it or admit failure
@@ -172,10 +173,14 @@ Returns a list of the CPANPLUS::Dist::* classes available
 ### will get overridden by Module::Pluggable if loaded
 ### XXX add support for 'plugin' dir in config as well
 {   my $Loaded;
-    my @Dists = (INSTALLER_BUILD, INSTALLER_MM);
+    my @Dists   = (INSTALLER_MM);
+    my @Ignore  = ();
 
     ### backdoor method to add more dist types
-    sub _add_dist_types { my $self = shift; push @Dists, @_ };
+    sub _add_dist_types     { my $self = shift; push @Dists,  @_ };
+    
+    ### backdoor method to exclude dist types
+    sub _ignore_dist_types  { my $self = shift; push @Ignore, @_ };
 
     ### locally add the plugins dir to @INC, so we can find extra plugins
     #local @INC = @INC, File::Spec->catdir(
@@ -192,22 +197,57 @@ Returns a list of the CPANPLUS::Dist::* classes available
 
             my $only_re = __PACKAGE__ . '::\w+$';
 
-            ### XXX M::P 2.4 can do regexes -- find out how
             Module::Pluggable->import(
                             sub_name    => '_dist_types',
                             search_path => __PACKAGE__,
                             only        => qr/$only_re/,
-                            except      => [ INSTALLER_MM, INSTALLER_SAMPLE,
-                                             INSTALLER_BUILD ],
+                            except      => [ INSTALLER_MM, INSTALLER_SAMPLE ]
                         );
-            push @Dists, grep { $_ !~ /CPANPLUS::Dist::Constants/ }
-                            __PACKAGE__->_dist_types;
+            my %ignore = map { $_ => $_ } @Ignore;                        
+                        
+            push @Dists, grep { not $ignore{$_}  } __PACKAGE__->_dist_types;
         }
 
         return @Dists;
     }
 }
 
+=head2 prereq_satisfied( modobj => $modobj, version => $version_spec )
+
+Returns true if this prereq is satisfied.  Returns false if it's not.
+Also issues an error if it seems "unsatisfiable," i.e. if it can't be
+found on CPAN or the latest CPAN version doesn't satisfy it.
+
+=cut
+
+sub prereq_satisfied {
+    my $dist = shift;
+    my $cb   = $dist->parent->parent;
+    my %hash = @_;
+  
+    my($mod,$ver);
+    my $tmpl = {
+        version => { required => 1, store => \$ver },
+        modobj  => { required => 1, store => \$mod, allow => IS_MODOBJ },
+    };
+    
+    check( $tmpl, \%hash ) or return;
+  
+    return 1 if $mod->is_uptodate( version => $ver );
+  
+    if ( $cb->_vcmp( $ver, $mod->version ) > 0 ) {
+
+        error(loc(  
+                "This distribution depends on %1, but the latest version".
+                " of %2 on CPAN (%3) doesn't satisfy the specific version".
+                " dependency (%4). You may have to resolve this dependency ".
+                "manually.", 
+                $mod->module, $mod->module, $mod->version, $ver ));
+  
+    }
+
+    return;
+}
 
 =head2 _resolve_prereqs
 
@@ -224,7 +264,7 @@ sub _resolve_prereqs {
     my $conf = $cb->configure_object;
     my %hash = @_;
 
-    my ($prereqs, $format, $verbose, $target, $force);
+    my ($prereqs, $format, $verbose, $target, $force, $prereq_build);
     my $tmpl = {
         ### XXX perhaps this should not be required, since it may not be
         ### packaged, just installed...
@@ -232,17 +272,18 @@ sub _resolve_prereqs {
         ### routine will figure it out, which is fine if we didn't have any
         ### very specific wishes (it will even detect the favourite
         ### dist_type).
-        format  => { required => 1, store => \$format,
-                        allow => ['',__PACKAGE__->dist_types], },
-        prereqs => { required => 1, default => { },
-                        strict_type => 1, store => \$prereqs },
-        verbose => { default => $conf->get_conf('verbose'),
-                        store => \$verbose },
-        force   => { default => $conf->get_conf('force'),
-                        store => \$force },
-                    ### make sure allow matches with $mod->install's list
-        target  => { default => '', allow => ['',qw[create ignore install]],
-                        store => \$target },
+        format          => { required => 1, store => \$format,
+                                allow => ['',__PACKAGE__->dist_types], },
+        prereqs         => { required => 1, default => { },
+                                strict_type => 1, store => \$prereqs },
+        verbose         => { default => $conf->get_conf('verbose'),
+                                store => \$verbose },
+        force           => { default => $conf->get_conf('force'),
+                                store => \$force },
+                        ### make sure allow matches with $mod->install's list
+        target          => { default => '', store => \$target,
+                                allow => ['',qw[create ignore install]] },
+        prereq_build    => { default => 0, store => \$prereq_build },
     };
 
     check( $tmpl, \%hash ) or return;
@@ -253,10 +294,10 @@ sub _resolve_prereqs {
     ### so you didn't provide an explicit target.
     ### maybe your config can tell us what to do.
     $target ||= {
-        PREREQ_ASK,     'install',   # we'll bail out if the user says no
-        PREREQ_BUILD,   'create',
-        PREREQ_IGNORE,  'ignore',
-        PREREQ_INSTALL, 'install',
+        PREREQ_ASK,     TARGET_INSTALL, # we'll bail out if the user says no
+        PREREQ_BUILD,   TARGET_CREATE,
+        PREREQ_IGNORE,  TARGET_IGNORE,
+        PREREQ_INSTALL, TARGET_INSTALL,
     }->{ $conf->get_conf('prereqs') } || '';
 
 
@@ -275,7 +316,7 @@ sub _resolve_prereqs {
         }
 
         ### it's not uptodate, we need to install it
-        if( !$modobj->is_uptodate(version => $version) ) {
+        if( !$dist->prereq_satisfied(modobj => $modobj, version => $version)) {
             msg(loc("Module '%1' requires '%2' version '%3' to be installed ",
                     $self->module, $modobj->module, $version), $verbose );
 
@@ -285,10 +326,10 @@ sub _resolve_prereqs {
         ### manager... we'll need to install it as well, via the PM
         } elsif ( INSTALL_VIA_PACKAGE_MANAGER->($format) and
                     !$modobj->package_is_perl_core and
-                    ($target ne 'ignore')
+                    ($target ne TARGET_IGNORE)
         ) {
-            msg(loc("Module '%1' depends on '%2', creating a '%3' package ".
-                    "for it as well", $self->module, $modobj->module,
+            msg(loc("Module '%1' depends on '%2', may need to build a '%3' ".
+                    "package for it as well", $self->module, $modobj->module,
                     $format));
             push @install_me, [$modobj, $version];
         }
@@ -297,7 +338,7 @@ sub _resolve_prereqs {
 
 
     ### so you just want to ignore prereqs? ###
-    if( $target eq 'ignore' ) {
+    if( $target eq TARGET_IGNORE ) {
 
         ### but you have modules you need to install
         if( @install_me ) {
@@ -325,6 +366,14 @@ sub _resolve_prereqs {
     for my $aref (@install_me) {
         my($modobj,$version) = @$aref;
 
+        ### another prereq may have already installed this one...
+        ### so dont ask again if the module turns out to be uptodate
+        ### see bug [#11840]
+        ### if either force or prereq_build are given, the prereq
+        ### should be built anyway
+        next if (!$force and !$prereq_build) && 
+                $dist->prereq_satisfied(modobj => $modobj, version => $version);
+
         ### either we're told to ignore the prereq,
         ### or the user wants us to ask him
         if( ( $conf->get_conf('prereqs') == PREREQ_ASK and not
@@ -374,10 +423,11 @@ sub _resolve_prereqs {
         ### CPANPLUS::Dist->new and the like ourselves,
         ### since ->install will take care of fetch &&
         ### extract as well
+        my $pa = $dist->status->_prepare_args   || {};
         my $ca = $dist->status->_create_args    || {};
         my $ia = $dist->status->_install_args   || {};
 
-        unless( $modobj->install(   %$ca, %$ia,
+        unless( $modobj->install(   %$pa, %$ca, %$ia,
                                     force   => $force,
                                     verbose => $verbose,
                                     format  => $format,
@@ -395,17 +445,13 @@ sub _resolve_prereqs {
         last if $flag;
 
         ### don't want us to install? ###
-        if( $target ne 'install' ) {
+        if( $target ne TARGET_INSTALL ) {
             my $dir = $modobj->status->extract
                         or error(loc("No extraction dir for '%1' found ".
                                      "-- weird", $modobj->module));
 
-            $cb->_add_to_includepath(
-                    directories => [
-                        File::Spec->catdir(BLIB->($dir), LIB),
-                        File::Spec->catdir(BLIB->($dir), ARCH),
-                    ]
-            );
+            $modobj->add_to_includepath();
+            
             next;
         }
     }
