@@ -312,14 +312,14 @@ sub _update_source {
 
 
         unless ($rv) {
-            error loc("Couldn't fetch '%1'", $file);
+            error( loc("Couldn't fetch '%1'", $file) );
             return;
         }
 
         ### `touch` the file, so windoze knows it's new -jmb
         ### works on *nix too, good fix -Kane
         utime ( $now, $now, File::Spec->catfile($path, $file) ) or
-            error loc("Couldn't touch %1", $file);
+            error( loc("Couldn't touch %1", $file) );
 
     }
     return 1;
@@ -406,7 +406,7 @@ sub _build_trees {
 #     my $id = $self->_store_id( $self );
 #
 #     unless ( $id == $self->_id ) {
-#         error loc("IDs do not match: %1 != %2. Storage failed!", $id, $self->_id);
+#         error( loc("IDs do not match: %1 != %2. Storage failed!", $id, $self->_id) );
 #     }
 
     return 1;
@@ -478,7 +478,7 @@ sub __retrieve_source {
                 );
 
     if ($storable && -e $stored && -s _ && $args->{'uptodate'}) {
-        msg loc("Retrieving %1", $stored), $args->{'verbose'};
+        msg( loc("Retrieving %1", $stored), $args->{'verbose'} );
 
         my $href = Storable::retrieve($stored);
         return $href;
@@ -555,16 +555,16 @@ sub _save_source {
                         );
 
     if (-e $stored && not -w $stored) {
-        msg loc("%1 not writable; skipped.", $stored), $args->{'verbose'};
+        msg( loc("%1 not writable; skipped.", $stored), $args->{'verbose'} );
         return;
     }
 
-    msg loc("Writing state information back to disk. This may take a little while."),
-	    $args->{'verbose'};
+    msg( loc("Writing state information back to disk. This may take a little while."),
+	    $args->{'verbose'} );
 
     my $flag;
     unless( Storable::nstore( $to_write, $stored ) ) {
-        error loc("could not store %1!", $stored);
+        error( loc("could not store %1!", $stored) );
         $flag++;
     }
 
@@ -776,8 +776,10 @@ sub _create_mod_tree {
 
         ### Every module get's stored as a module object ###
         $tree->{ $data[0] } = CPANPLUS::Module->new(
-                module      => $data[0],    # full module name
-                version     => $data[1],    # version number
+                module      => $data[0],            # full module name
+                version     => ($data[1] eq 'undef' # version number 
+                                    ? '0.0' 
+                                    : $data[1]), 
                 path        => File::Spec::Unix->catfile(
                                     $conf->_get_mirror('base'),
                                     $data[2],
@@ -880,12 +882,15 @@ sub __create_dslip_tree {
     ### $cols = [....]
     ### and newer versions say:
     ### $CPANPLUS::Modulelist::cols = [...]
-    $in =~ s|.+}\s+(\$(?:CPAN::Modulelist::)?cols)|$1|s;
-
     ### split '$cols' and '$data' into 2 variables ###
-    my ($ds_one, $ds_two) = split ';', $in, 2;
+    ### use this regex to make sure dslips with ';' in them don't cause
+    ### parser errors
+    my ($ds_one, $ds_two) = ($in =~ m|.+}\s+
+										(\$(?:CPAN::Modulelist::)?cols.*?)
+										(\$(?:CPAN::Modulelist::)?data.*)
+									|sx);
 
-    ### eval them into existance ###
+    ### eval them into existence ###
     ### still not too fond of this solution - kane ###
     my ($cols, $data);
     {   #local $@; can't use this, it's buggy -kane
