@@ -117,7 +117,7 @@ include facility from C<CPANPLUS::inc>. It will roughly look like:
 
     sub original_perl5opt   { $org_opt || ''};
     sub original_perl5lib   { $org_lib || ''};
-    sub original_inc        { @org_inc };
+    sub original_inc        { @org_inc, __PACKAGE__->my_path };
 
     sub limited_perl5opt    {
         my $pkg = shift;
@@ -153,13 +153,12 @@ It would looks something like this:
     my $map = {
         'File::Fetch'               => '0.07',
         #'File::Spec'                => '0.82', # can't, need it ourselves...
-        'IPC::Run'                  => '0.77',
+        'IPC::Run'                  => '0.80',
         'IPC::Cmd'                  => '0.24',
         'Locale::Maketext::Simple'  => 0,
         'Log::Message'              => 0,
         'Module::Load'              => '0.10',
-        'Module::Load::Conditional' => '0.06',
-        'Module::Build'             => '0.26061',
+        'Module::Load::Conditional' => '0.07',
         'Params::Check'             => '0.22',
         'Term::UI'                  => '0.05',
         'Archive::Extract'          => '0.07',
@@ -167,6 +166,7 @@ It would looks something like this:
         'IO::Zlib'                  => '1.04',
         'Object::Accessor'          => '0.03',
         'Module::CoreList'          => '1.97',
+        'Module::Pluggable'         => '2.4',
         #'Config::Auto'             => 0,   # not yet, not using it yet
     };
 
@@ -278,15 +278,16 @@ find out exactly what C<CPANPLUS::inc> is doing.
         ### we care about. very basic check, but will
         ### have to do for now.
         lib->import( sub {
-            my $path    = pop();                # path to the pm
-            my $module  = $path or return;      # copy of the path, to munge
-            my @parts   = split '/', $path;     # dirs + file name
-            my $file    = pop @parts;           # just the file name
+            my $path    = pop();                    # path to the pm
+            my $module  = $path or return;          # copy of the path, to munge
+            my @parts   = split qr!\\|/!, $path;    # dirs + file name; could be
+                                                    # win32 paths =/
+            my $file    = pop @parts;               # just the file name
             my $map     = __PACKAGE__->interesting_modules;
 
-
-            ### translate file name to module name ###
-            $module =~ s|/|::|g; $module =~ s/\.pm//i;
+            ### translate file name to module name 
+            ### could contain win32 paths delimiters
+            $module =~ s!/|\\!::!g; $module =~ s/\.pm//i;
 
             my $check_version; my $try;
             ### does it look like a module we care about?
@@ -379,7 +380,7 @@ find out exactly what C<CPANPLUS::inc> is doing.
             ### or otherwise, the one not bundled
             ### or otherwise the newest
             my @sorted = sort {
-                            ($b->[0] <=> $a->[0])                   ||
+                            _vcmp($b->[0], $a->[0])                  ||
                             ($Cache{$interesting}
                                 ?($b->[2] eq $Cache{$interesting}->[0][2]) <=>
                                  ($a->[2] eq $Cache{$interesting}->[0][2])
@@ -393,7 +394,9 @@ find out exactly what C<CPANPLUS::inc> is doing.
                              ."'$sorted[0][2]' with version '$sorted[0][0]'\n"
                     if $DEBUG;
 
-            if( $check_version and not ($sorted[0][0] >= $map->{$module}) ) {
+            if( $check_version and 
+                not (_vcmp($sorted[0][0], $map->{$module}) >= 0) 
+            ) {
                 warn __PACKAGE__ .": Cannot find high enough version for "
                                  ."'$module' -- need '$map->{$module}' but "
                                  ."only found '$sorted[0][0]'. Returning "
@@ -428,6 +431,13 @@ find out exactly what C<CPANPLUS::inc> is doing.
     }
 }
 
+### XXX copied from C::I::Utils, so there's no circular require here!
+sub _vcmp {
+    my ($x, $y) = @_;
+    s/_//g foreach $x, $y;
+    return $x <=> $y;
+}
+
 =pod
 
 =head1 DEBUG
